"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _initReplicationStateTable = _interopRequireDefault(require("./init-replication-state-table"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const setReplicationLock = async (pool, lockId, lockDuration) => {
  const {
    executeStatement,
    escapeId
  } = pool;
  const replicationStateTableName = await (0, _initReplicationStateTable.default)(pool);

  if (lockDuration <= 0) {
    const rows = await executeStatement(`UPDATE ${escapeId(replicationStateTableName)} 
    SET
      "LockExpirationTime" = 0,
      "LockId" = NULL
    WHERE "LockId" = ${pool.escape(lockId)}
    RETURNING "LockExpirationTime", "LockId"`);
    return rows.length !== 0;
  } else {
    const rows = await executeStatement(`UPDATE ${escapeId(replicationStateTableName)} 
    SET
      "LockExpirationTime" = CAST(strftime('%s','now') || substr(strftime('%f','now'),4) AS INTEGER) + ${+lockDuration},
      "LockId" = ${pool.escape(lockId)}
    WHERE "LockExpirationTime" < CAST(strftime('%s','now') || substr(strftime('%f','now'),4) AS INTEGER)
    RETURNING "LockExpirationTime"`);
    return rows.length !== 0;
  }
};

var _default = setReplicationLock;
exports.default = _default;
//# sourceMappingURL=set-replication-lock.js.map